Index: usr.sbin/adduser/adduser.sh
===================================================================
--- usr.sbin/adduser/adduser.sh	(revision 358732)
+++ usr.sbin/adduser/adduser.sh	(working copy)
@@ -332,6 +332,29 @@
 			info "Sent welcome message to ($username)."
 		}
 	fi
+
+	# If we have some plug-ins, execute them.
+	if [ -d ${plugindir} ]; then
+		slist=""
+		if [ -z "${script_name_sep}" ]; then
+			script_name_sep=" "
+		fi
+		for script in ${plugindir}/*.sh; do
+			slist="${slist}${script_name_sep}${script}"
+		done
+		script_save_sep="$IFS"
+		IFS="${script_name_sep}"
+		for script in ${slist}; do
+			if [ -x "${script}" ]; then
+				(set -T
+				trap 'exit 1' 2
+				${script} add ${username})
+			elif [ -f "${script}" -o -L "${script}" ]; then
+				echo -n " (skipping ${script##*/}, not executable)"
+			fi
+		done
+		IFS="${script_save_sep}"
+	fi
 }
 
 # get_user
@@ -885,6 +908,7 @@
 defaultLgroup=
 defaultgroups=
 defaultshell="${DEFAULTSHELL}"
+plugindir=/usr/local/share/adduser
 defaultHomePerm=
 
 # Make sure the user running this program is root. This isn't a security
Index: usr.sbin/adduser/rmuser.sh
===================================================================
--- usr.sbin/adduser/rmuser.sh	(revision 358732)
+++ usr.sbin/adduser/rmuser.sh	(working copy)
@@ -220,6 +220,45 @@
 	echo "       one or more user names must be given"
 }
 
+reverse_list()
+{
+	_revlist=
+	for _revfile in $*; do
+		_revlist="$_revfile $_revlist"
+	done
+	echo $_revlist
+}
+
+#
+# plugins
+#	username
+#	execute plugins in rm mode
+#
+plugins() {
+	# If we have some plug-ins, execute them.
+	if [ -d ${plugindir} ]; then
+		slist=""
+		if [ -z "${script_name_sep}" ]; then
+			script_name_sep=" "
+		fi
+		for script in ${plugindir}/*.sh; do
+			slist="${slist}${script_name_sep}${script}"
+		done
+		script_save_sep="$IFS"
+		IFS="${script_name_sep}"
+		for script in `reverse_list ${slist}`; do
+			if [ -x "${script}" ]; then
+				(set -T
+				trap 'exit 1' 2
+				${script} rm $1)
+			elif [ -f "${script}" -o -L "${script}" ]; then
+				echo -n " (skipping ${script##*/}, not executable)"
+			fi
+		done
+		IFS="${script_save_sep}"
+	fi
+}
+
 #### END SUBROUTINE DEFENITION ####
 
 ffile=
@@ -229,6 +268,7 @@
 userlist=
 yflag=
 vflag=
+plugindir=/usr/local/share/adduser
 
 procowner=`/usr/bin/id -u`
 if [ "$procowner" != "0" ]; then
@@ -359,5 +399,6 @@
 	rm_files $_user
 	rm_mail $_user
 	rm_user $_user
+	plugins $_user
 	! verbose && echo "."
 done
